class NHCActionEvent:
    @property
    def value1(self) -> str:
        return self._value1
    
    @property
    def id(self) -> str:
        return self._id
    
    def __init__(self, event: str):
        self._id = event["id"]
        self._value1 = event["value1"]

class NHCEnergyEvent():
    @property
    def channel(self) -> str:
        return self._channel
    
    @property
    def v(self) -> str:
        return self._v
    
    def __init__(self, event: str):
        self._channel = event["channel"]
        self._v = event["v"]

class NHCThermostatEvent: 
    @property
    def mode(self) -> str:
        return self._mode
    
    @property
    def setpoint(self) -> str:
        return self._setpoint
    
    @property
    def measured(self) -> str:
        return self._measured
    
    @property
    def overrule(self) -> str:
        return self._overrule
    
    @property
    def overruletime(self) -> str:
        return self._overruletime
    
    @property
    def ecosave(self) -> str:
        return self._ecosave
    
    def __init__(self, event: str):
        self._mode = event["mode"]
        self._setpoint = event["setpoint"]
        self._measured = event["measured"]
        self._overrule = event["overrule"]
        self._overruletime = event["overruletime"]
        self._ecosave = event["ecosave"]


from .action import NHCAction
from .const import COVER_OPEN, COVER_CLOSE, COVER_STOP

class NHCCover(NHCAction):

    @property
    def is_open(self) -> bool:
        return self._state > 0

    def open(self) -> None:
        self._controller.execute(self.id, COVER_OPEN)

    def close(self) -> None:
        self._controller.execute(self.id, COVER_CLOSE)

    def stop(self) -> None:
        self._controller.execute(self.id, COVER_STOP)



from .action import NHCBaseAction

class NHCThermostat(NHCBaseAction):
    def __init__(self, controller, data):
        super().__init__(controller, data)
        self._measured = data["measured"]
        self._setpoint = data["setpoint"]
        self._overrule = data["overrule"]
        self._overruletime = data["overruletime"]
        self._ecosave = data["ecosave"]
    
    @property
    def measured(self):
        return self._measured

    @property
    def setpoint(self):
        return self._setpoint
    
    @property
    def mode(self):
        return self._state
    
    @property
    def overrule(self):
        return self._overrule
    
    @property
    def overruletime(self):
        return self._overruletime
    
    @property
    def ecosave(self):
        return self._ecosave
    
    def set_mode(self, mode):
        self._controller.execute_thermostat(self.id, mode, self._overruletime, self._overrule, self._setpoint)

    def set_temperature(self, setpoint):
        self._controller.execute_thermostat(self.id, self._state, self._overruletime, self._overrule, setpoint)
    
    def update_state(self, data):
        self._state = data["mode"]
        self._setpoint = data["setpoint"]
        self._measured = data["measured"]
        self._overrule = data["overrule"]
        self._overruletime = data["overruletime"]
        self._ecosave = data["ecosave"]




MODES = ['low', 'medium', 'high', 'boost']
PRESET_MODES = {'boost': 3, 'high': 2, 'medium': 1, 'low': 0}

COVER_OPEN = 255
COVER_CLOSE = 254
COVER_STOP = 253

DEFAULT_PORT = 8000

THERMOSTAT_MODES = {
    0: "day",
    1: "night",
    2: "eco",
    3: "off",
    4: "cool",
    5: "prog1",
    6: "prog2",
    7: "prog3",
}

ENERGY_TYPES = {
    0: "import",
    1: "sub_usage", 
    2: "export",
}